==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionIconMenuDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionIconButtonDescriptionMetadata } from "./ToolActionIconButtonDescriptionMetadata";
import { ToolActionIconMenuDescription } from "./ToolActionIconMenuDescription";
/**
 * @hidden
 */
export let ToolActionIconMenuDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconMenuDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconMenuDescriptionMetadata.a == null) {
                ToolActionIconMenuDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconMenuDescriptionMetadata.c(ToolActionIconMenuDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconMenuDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionIconMenuDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionIconButtonDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionIconMenuDescriptionMetadata.b(a);
            a.ad("ToolActionIconMenu", () => new ToolActionIconMenuDescription());
            a.ac("ToolActionIconMenu", ToolActionIconMenuDescriptionMetadata.a);
        }
    }
    ToolActionIconMenuDescriptionMetadata.$t = markType(ToolActionIconMenuDescriptionMetadata, 'ToolActionIconMenuDescriptionMetadata');
    ToolActionIconMenuDescriptionMetadata.a = null;
    return ToolActionIconMenuDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionIconMenuDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionIconButtonDescriptionMetadata } from "./ToolActionIconButtonDescriptionMetadata";
import { ToolActionIconMenuDescription } from "./ToolActionIconMenuDescription";
/**
 * @hidden
 */
export let ToolActionIconMenuDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconMenuDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconMenuDescriptionMetadata.a == null) {
                ToolActionIconMenuDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconMenuDescriptionMetadata.c(ToolActionIconMenuDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconMenuDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionIconMenuDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionIconButtonDescriptionMetadata.c(a);
            a.item("ArrowStroke", "Brush");
            a.item("ActualArrowStroke", "Brush");
            a.item("ShowArrowIcon", "Boolean");
        }
        static d(a) {
            ToolActionIconMenuDescriptionMetadata.b(a);
            a.ae("ToolActionIconMenu", () => new ToolActionIconMenuDescription());
            a.ad("ToolActionIconMenu", ToolActionIconMenuDescriptionMetadata.a);
        }
    }
    ToolActionIconMenuDescriptionMetadata.$t = markType(ToolActionIconMenuDescriptionMetadata, 'ToolActionIconMenuDescriptionMetadata');
    ToolActionIconMenuDescriptionMetadata.a = null;
    return ToolActionIconMenuDescriptionMetadata;
})();
